@@ -1,5 +1,5 @@
 import argparse
-import vcftoabook
+import vcftoabook.functions as functions
 
 
 def main():
@@ -23,15 +23,17 @@ def main():
         help="the output path/filename (default: ./addressbook)"
     )
 
+    '''
     parser.add_argument(
         '-a',
         '--append',
         action='store_true',
         help="append new contacts to existing address book"
     )
+    '''
     args = parser.parse_args()
 
-    vcftoabook.main(args)
+    functions.main(args)
 
 
 if __name__ == '__main__':
